@@ -283,8 +283,14 @@ class BlobsMixin:
                 f"Unable to download blob {blob_id}: {response.status_code}"
             )
 
-    def get_blobs(self):
-        return self.get("blobs")["result"]["blobs"]
+    def get_blobs(self, include_deleted=None, include_metadata=None):
+        return self.get(
+            "blobs",
+            params=dict(
+                include_deleted=Boolean.to_str(include_deleted),
+                include_metadata=Boolean.to_str(include_metadata),
+            ),
+        )["result"]["blobs"]
 
     def tag_blobs(self, blob_ids, tag):
         post_data = [{"blob_id": blob_id, "tag": tag} for blob_id in blob_ids]
@@ -305,9 +311,8 @@ class BlobsMixin:
 
 
 class LoginMixin:
-    def login_transfer(self, user, lifespan=600):
-        data = {"lifespan": lifespan}
-        answer = self.post(("login", "transfer", user), json=data)
+    def login_transfer(self, user):
+        answer = self.post(("login", "transfer", user))
         return answer["result"]["token"]
 
     def login_federate(self, origin_server, origin_token, federated_group):
@@ -350,12 +355,25 @@ class Boolean:
         "false": False,
     }
 
-    def from_str(self, value):
+    @classmethod
+    def from_str(cls, value):
         try:
-            return self.BOOLEAN_LOOKUP[value.lower()]
+            return cls.BOOLEAN_LOOKUP[value.lower()]
         except KeyError:
             raise ValueError(f"Cannot convert {value} to boolean.")
 
+    @classmethod
+    def to_str(cls, value):
+        """Uniformly return yes or no for truthy ``values``.
+
+        Leave None unchanged so that URL flags aren't included in requests.
+        """
+        if isinstance(value, str):
+            value = cls.from_str(value)
+        if value is None:
+            return None
+        return "yes" if bool(value) else "no"
+
 
 class CsvResponse:
     """Iterable returned from a task or view when responding with non-downloaded CSV."""
@@ -753,7 +771,7 @@ class MiscMixin:
         url = "/".join([self.url, namespace, wheelhouse])
         with download_to_file(url, self.token) as tmp_filename:
             with untar_to_dir(tmp_filename) as tmp_dir:
-                subprocess.check_call(
+                proc = subprocess.run(
                     [
                         sys.executable,
                         "-m",
@@ -764,8 +782,12 @@ class MiscMixin:
                         tmp_dir,
                         "--requirement",
                         tmp_dir / "requirements.txt",
-                    ]
+                    ],
+                    check=True,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT,
                 )
+                print(proc.stdout.decode())
 
 
 class ConfigMixin:
@@ -775,10 +797,14 @@ class ConfigMixin:
 
     def get_config(self, key):
         """Return server configuration value for given key."""
-        try:
-            return self.get(("config", key))["result"][key]
-        except encapsia_api.EncapsiaApiError:
+        response = self.get(
+            ("config", key),
+            expected_codes=(200, 201, 404),
+            return_json=False,
+        )
+        if response.status_code == 404:
             raise KeyError(key)
+        return response.json()["result"][key]
 
     def set_config(self, key, value):
         """Set server configuration value for given key."""
